@@ -33,6 +33,7 @@ __all__ = [
 from datetime import datetime, date
 from email.utils import formatdate
 import copy
+from operator import itemgetter
 import os
 import simplejson
 import simplejson.encoder
@@ -911,7 +912,7 @@ class ReadWriteResource(HTTPResource):
 
     def __call__(self):
         """Handle a GET, PUT, or PATCH request."""
-        result = ""
+        result = b""
         method = self.getRequestMethod()
         try:
             if method == "GET":
@@ -988,7 +989,7 @@ class EntryHTMLView:
             HTTPResource.XHTML_TYPE).items()
         data = [{'name' : name, 'value': decode_value(value)}
                 for name, value in names_and_values]
-        namespace['context'] = sorted(data)
+        namespace['context'] = sorted(data, key=itemgetter('name'))
         return self.HTML_TEMPLATE.pt_render(namespace)
 
 
@@ -1117,9 +1118,13 @@ class EntryManipulatingResource(ReadWriteResource):
 
             if IBytes.providedBy(field):
                 # We don't modify Bytes fields from the Entry that contains
-                # them, but we may tell users how to do so if they attempt to
-                # change them.
-                if value != current_value:
+                # them, but we may tell users how to do so if they attempt
+                # to change them.  The encode call is because
+                # BytesFieldMarshaller.unmarshall returns a link to the byte
+                # storage resource as a str, but
+                # BytesFieldMarshaller.marshall_from_json_data returns
+                # bytes.
+                if value != current_value.encode('UTF-8'):
                     if field.readonly:
                         errors.append(modified_read_only_attribute
                                       % repr_name)
@@ -1251,7 +1256,7 @@ class EntryManipulatingResource(ReadWriteResource):
             self.request.response.setStatus(209)
             media_type = self.getPreferredSupportedContentType()
             self.request.response.setHeader('Content-type', media_type)
-            return self._representation(media_type)
+            return self._representation(media_type).encode('UTF-8')
         else:
             # The object moved. Serve a redirect to its new location.
             # This might not necessarily be the location of the entry!
@@ -1288,10 +1293,10 @@ class EntryFieldResource(FieldUnmarshallerMixin, EntryManipulatingResource):
         media_type = self.handleConditionalGET()
         if media_type is None:
             # The conditional GET succeeded. Serve nothing.
-            return ""
+            return b""
         else:
             self.request.response.setHeader('Content-Type', media_type)
-            return self._representation(media_type)
+            return self._representation(media_type).encode('UTF-8')
 
     def do_PUT(self, media_type, representation):
         """Overwrite the field's existing value with a new value."""
@@ -1328,7 +1333,7 @@ class EntryFieldResource(FieldUnmarshallerMixin, EntryManipulatingResource):
         elif media_type == self.XHTML_TYPE:
             name, value = self.unmarshallFieldToHTML(
                 self.context.name, self.context.field)
-            return encode_value(value)
+            return decode_value(value)
         else:
             raise AssertionError(
                     "No representation implementation for media type %s"
@@ -1564,10 +1569,10 @@ class EntryResource(CustomOperationResourceMixin,
             media_type = self.handleConditionalGET()
             if media_type is None:
                 # The conditional GET succeeded. Serve nothing.
-                return ""
+                return b""
             else:
                 self.request.response.setHeader('Content-Type', media_type)
-                return self._representation(media_type)
+                return self._representation(media_type).encode('UTF-8')
 
     def do_PUT(self, media_type, representation):
         """Modify the entry's state to match the given representation.
@@ -1708,7 +1713,7 @@ class EntryResource(CustomOperationResourceMixin,
         """Return a representation of this entry, of the given media type."""
 
         if media_type in [self.WADL_TYPE, self.DEPRECATED_WADL_TYPE]:
-            return self.toWADL().encode("utf-8")
+            return self.toWADL()
         elif media_type in (self.JSON_TYPE, self.JSON_PLUS_XHTML_TYPE):
             cache = self._representation_cache
             if cache is None:
@@ -1754,7 +1759,7 @@ class EntryResource(CustomOperationResourceMixin,
                     representation = simplejson.dumps(json)
             return representation
         elif media_type == self.XHTML_TYPE:
-            return self.toXHTML().encode("utf-8")
+            return self.toXHTML()
         else:
             raise AssertionError(
                     "No representation implementation for media type %s"
@@ -1929,16 +1934,16 @@ class ServiceRootResource(HTTPResource):
         self.setCachingHeaders()
         if media_type is None:
             # The conditional GET succeeded. Serve nothing.
-            return ""
+            return b""
         elif media_type in [self.WADL_TYPE, self.DEPRECATED_WADL_TYPE]:
-            result = self.toWADL().encode("utf-8")
+            result = self.toWADL()
         elif media_type == self.JSON_TYPE:
             # Serve a JSON map containing links to all the top-level
             # resources.
             result = simplejson.dumps(self, cls=ResourceJSONEncoder)
 
         self.request.response.setHeader('Content-Type', media_type)
-        return result
+        return result.encode("utf-8")
 
     def toWADL(self):
         # Find all resource types.
