@@ -43,6 +43,7 @@ __all__ = [
     'webservice_error',
     ]
 
+from collections import OrderedDict
 import copy
 import itertools
 import sys
@@ -1019,7 +1020,7 @@ class export_factory_operation(_export_operation):
         # pylint: disable-msg=W0231
         _check_called_from_interface_def('%s()' % self.__class__.__name__)
         self.interface = interface
-        self.params = {}
+        self.params = OrderedDict()
         for name in field_names:
             field = interface.get(name)
             if field is None:
@@ -1519,7 +1520,7 @@ class BaseResourceOperationAdapter(ResourceOperation):
             (param_def.__name__, orig_name)
             for orig_name, param_def in self._export_info['params'].items()
             if param_def.__name__ != orig_name)
-        params = {}
+        params = OrderedDict()
         for name, value in kwargs.items():
             name = renames.get(name, name)
             params[name] = value
