@@ -2,22 +2,23 @@
 
 """Martian directives used in lazr.restful."""
 
+from __future__ import absolute_import, print_function
+
 __metaclass__ = type
 __all__ = ['request_class',
            'publication_class',
            'settings',]
 
 import martian
-from zope.component import getSiteManager, getUtility
+from zope.component import getSiteManager
 from zope.location.interfaces import ILocation
-from zope.interface import alsoProvides
 from zope.interface.interface import InterfaceClass
 from zope.traversing.browser import AbsoluteURL
 from zope.traversing.browser.interfaces import IAbsoluteURL
 
 from lazr.restful.interfaces import (
     IServiceRootResource, IWebServiceClientRequest, IWebServiceConfiguration,
-    IWebServiceLayer, IWebServiceVersion)
+    IWebServiceLayer)
 from lazr.restful._resource import (
     register_versioned_request_utility, ServiceRootResource)
 from lazr.restful.simple import (
