@@ -238,6 +238,11 @@ class IRecipeSet(IHasGet):
     def getRecipes():
         """Return the list of recipes."""
 
+    @export_factory_operation(
+        IRecipe, ['id', 'cookbook', 'dish', 'instructions', 'private'])
+    def createRecipe(id, cookbook, dish, instructions, private=False):
+        """Create a new recipe."""
+
     def removeRecipe(recipe):
         """Remove a recipe from the list."""
 
