@@ -2,10 +2,11 @@
 
 """Event listeners for the example web service."""
 
+from __future__ import absolute_import, print_function
+
 __metaclass__ = type
 __all__ = ['update_cookbook_revision_number']
 
-from zope.interface import Interface
 import grokcore.component
 from lazr.lifecycle.interfaces import IObjectModifiedEvent
 from lazr.restful.example.base.interfaces import ICookbook
