@@ -26,8 +26,9 @@ __all__ = [
 
 from datetime import datetime
 from io import BytesIO
-import pytz
+import re
 
+import pytz
 import simplejson
 import six
 from six.moves.urllib.parse import unquote
@@ -290,21 +291,27 @@ class BytesFieldMarshaller(SimpleFieldMarshaller):
         return "%s/%s" % (absoluteURL(entry.context, self.request),
                           self.field.__name__)
 
-    def _marshall_from_request(self, value):
-        """See `SimpleFieldMarshaller`.
+    def marshall_from_request(self, value):
+        """See `IFieldMarshaller`.
 
         Reads the data from file-like object, and converts non-strings into
-        one.
+        one.  This overrides `marshall_from_request` rather than
+        implementing the `_marshall_from_request` hook method because we
+        need to suppress the default JSON-decoding behaviour: binary data
+        can't be marshalled via JSON without additional encoding that we
+        don't do, and lazr.restfulclient doesn't JSON-encode binary fields.
         """
+        if value is None:
+            return None
         if safe_hasattr(value, 'seek'):
             value.seek(0)
             value = value.read()
         elif not isinstance(value, (bytes, six.text_type)):
-            value = bytes(value)
+            value = str(value).encode('UTF-8')
         else:
             # Leave string conversion to _marshall_from_json_data.
             pass
-        return super(BytesFieldMarshaller, self)._marshall_from_request(value)
+        return self._marshall_from_json_data(value)
 
     def _marshall_from_json_data(self, value):
         """See `SimpleFieldMarshaller`.
@@ -329,6 +336,10 @@ class TextFieldMarshaller(SimpleFieldMarshaller):
         Converts the value to unicode.
         """
         value = six.text_type(value)
+        # multipart/form-data encoding of text fields is required (RFC 2046
+        # section 4.1.1) to use CRLF for line breaks.  Normalize to
+        # Unix-style LF.
+        value = re.sub(r'\r\n?', '\n', value)
         return super(TextFieldMarshaller, self)._marshall_from_request(value)
 
 
