@@ -479,7 +479,7 @@ def generate_and_register_webservice_operations(
     registered_adapters = set()
     block_mutator_operations = set()
 
-    methods = interface.namesAndDescriptions(True)
+    methods = list(interface.namesAndDescriptions(True))
     for iface in REGISTERED_CONTRIBUTORS[interface]:
         methods.extend(iface.namesAndDescriptions(True))
 
